@@ -1,8 +1,7 @@
 package  # hide from PAUSE
    P9Y::ProcessTable;
 
-our $VERSION = '0.90'; # VERSION
-# ABSTRACT: Darwin/OSX process table
+our $VERSION = '0.91'; # VERSION
 
 #############################################################################
 # Modules
@@ -41,6 +40,15 @@ sub list {
    return sort { $a <=> $b } map { $_->pid } @{ $pt->table };
 }
 
+sub fields {
+   return ( qw/
+      pid uid gid euid egid suid sgid ppid pgrp sess
+      cmdline 
+      utime stime start time
+      priority fname state ttynum ttydev flags size rss wchan cpuid pctcpu pctmem
+   / );
+}
+
 sub _process_hash {
    my ($self, $pid) = @_;
    my $info = first { $_->pid == $pid } @{ $pt->table };
@@ -53,46 +61,18 @@ sub _convert_hash {
    return unless $info;
    
    my $hash = {};
+   # (only has the ones that are different)
    state $stat_loc = { qw/
-      pid       pid     
-      ppid      ppid    
-      pgrp      pgrp    
-      uid       uid     
-      gid       gid     
-      euid      euid    
-      egid      egid    
-      suid      suid    
-      sgid      sgid    
-      priority  priority
-      size      size    
-      rss       rss     
-      flags     flags   
-      nice      nice    
-      sess      sess    
-      time      time    
-      stime     stime   
-      utime     utime   
-      start     start   
-      wchan     wchan   
-      ttydev    ttydev  
-      ttynum    ttynum  
-      pctcpu    pctcpu  
-      pctmem    pctmem  
-      state     state   
       cmdline   cmndline
-      fname     fname   
    / };
    
-   foreach my $key (keys %$stat_loc) {
-      no strict 'refs';
-      my $old = $stat_loc->{$key};
+   no strict 'refs';
+   foreach my $key ( $self->fields ) {
+      my $old = $stat_loc->{$key} || $key;
       my $item = $info->$old();
       $hash->{$key} = $item if defined $item;
    }
    
-   $hash->{ ttlflt} = $hash->{ minflt} + $hash->{ majflt};
-   $hash->{cttlflt} = $hash->{cminflt} + $hash->{cmajflt};
-   
    return $hash;
 }
 
@@ -105,7 +85,7 @@ __END__
 
 =head1 NAME
 
-P9Y::ProcessTable - Darwin/OSX process table
+P9Y::ProcessTable
 
 =head1 AVAILABILITY
 
