@@ -1,8 +1,7 @@
 package  # hide from PAUSE
    P9Y::ProcessTable;
 
-our $VERSION = '0.90'; # VERSION
-# ABSTRACT: VMS process table
+our $VERSION = '0.91'; # VERSION
 
 #############################################################################
 # Modules
@@ -33,6 +32,15 @@ sub list {
    return sort { $a <=> $b } map { $_->{PID} } (process_list);
 }
 
+sub fields {
+   return ( qw/
+      pid uid gid ppid pgrp
+      exe
+      ttlflt start time
+      priority fname state ttydev flags size rss cpuid
+   / );
+}
+
 sub _process_hash {
    my ($self, $pid) = @_;
    my $info = process_list({
@@ -57,7 +65,7 @@ sub _convert_hash {
       cpuid       CPUID
       priority    PRI
       flags       PHDFLAGS
-      minflt      PAGEFLTS
+      ttlflt      PAGEFLTS
       time        CPUTIM
       size        VIRTPEAK
       rss         WSSIZE
@@ -86,7 +94,7 @@ __END__
 
 =head1 NAME
 
-P9Y::ProcessTable - VMS process table
+P9Y::ProcessTable
 
 =head1 AVAILABILITY
 
